/* KallistiGL for KOS 1.1.7

   glinternal.c
   (c)2001 Dan Potter

   $Id: glinternal.h,v 1.8 2002/03/17 06:24:38 axlen Exp $
*/

#ifndef __GL_GLINTERNAL_H
#define __GL_GLINTERNAL_H

/* Implementation details; not to be used externally */
#include <GL/gl.h>
#include <dc/pvr.h>
#include <dcutils/3dutils.h>

/* AFAIK, the PowerVR simulates a 32bit depth buffer */
#define DEPTHBUFFER_MAX ((GLfloat)0xffffffff)

/* "Clear color" -- really the background plane color */
extern GLfloat gl_clear_color[4];

/* Capability mask (for glEnable() and glDisable()) */
extern GLbitfield gl_capabilities;

/* Enabled lists (PVR specific) */
extern GLbitfield gl_enabled_lists;

/* Current primitive type (GL_TRIANGLES, etc) */
extern GLenum gl_prim_type;

/* Current polygon context */
extern pvr_poly_cxt_t gl_poly_cxt;

/* Poly header buffer submitted? */
extern GLboolean gl_pbuf_submitted;

/* Current Blend functions */
extern GLint gl_blend_src;
extern GLint gl_blend_dst;

/* Currently selected texture header */
extern pvr_poly_cxt_t *gl_cur_texture;

/* a "null" texture header for colored polys */
extern pvr_poly_cxt_t gl_null_texture;

/* Depth range */
extern GLclampf gl_depthrange_near;
extern GLclampf gl_depthrange_far;

/* Screen size */
extern GLsizei gl_screen_width;
extern GLsizei gl_screen_height;

/* Viewport size */
extern GLint gl_viewport_x1, gl_viewport_y1,
	gl_viewport_width, gl_viewport_height;

/* Viewport mapping */
extern GLfloat gl_viewport_scale[3];
extern GLfloat gl_viewport_offset[3];

/* Scissor clipping */
extern GLint gl_scissor_x;
extern GLint gl_scissor_y;
extern GLsizei gl_scissor_width;
extern GLsizei gl_scissor_height;
extern GLboolean gl_scissor_dirty;

/* Transformation matrices; possibilities are:
   GL_MODELVIEW
   GL_PROJECTION
   GL_TEXTURE
*/
extern matrix_t gl_trans_mats[GL_MATRIX_COUNT]  __attribute__((aligned(32)));
extern int gl_matrix_mode;
extern GLboolean gl_matrix_dirty;

/* Some happy macros */
#define TXR_ENABLED (gl_capabilities & GL_TEXTURE_2D)
#define AUTOUV_ENABLED (gl_capabilities & GL_KOS_AUTO_UV)
#define FOG_ENABLED (gl_capabilities & GL_FOG)
#define BLEND_ENABLED (gl_capabilities & GL_BLEND)
#define SCISSOR_ENABLED (gl_capabilities & GL_SCISSOR_TEST)
#define USERCLIP_OUTSIDE_ENABLED (gl_capabilities & GL_KOS_USERCLIP_OUTSIDE)

/* Currently active list */
extern GLbitfield gl_active_list;

/* Face culling enabled/disabled */
extern GLboolean gl_cull_face;

/* Front face */
extern GLenum gl_front_face;

/* Culling mode */
extern GLenum gl_cull_mode;

/* Fog Attributes */ 
extern GLfloat gl_fog_color[4];
extern GLfloat gl_fog_density;
extern GLfloat gl_fog_start;
extern GLfloat gl_fog_end;
extern GLfloat gl_fog_index; /* unused */
extern GLenum  gl_fog_mode;

/* Point size */
extern GLfloat gl_point_size; 

#endif	/* __GL_GLINTERNAL_H */

